@@ -3,7 +3,6 @@ from django.utils.translation import ugettext_lazy as _
 
 from .registry import Registry
 from .route import Route
-from .views.debug import UrlsView
 from .views.generic import TemplateView
 
 
@@ -13,16 +12,18 @@ site = Registry(
             LoginView,
             title_html=_('Login'),
             redirect_authenticated_user=True,
-            allowed=True,
+            authenticate=False,
+        ),
+        Route.factory(
+            LogoutView,
+            authenticate=False,
         ),
-        Route.factory(LogoutView),
-        UrlsView,
         TemplateView.clone(
             template_name='crudlfap/home.html',
             title_heading='',
             urlname='home',
             urlpath='',
-            allowed=True,
+            authenticate=False,
         )
     ]
 )
